#!/bin/bash

# Capture output and errors from ldconfig (refresh shared library cache)
output=$(sudo ldconfig 2>&1)
echo "ldconfig output: $output"

# Check the output
if [ -n "$output" ]; then  # -n checks if the string is not empty
    # If output is not empty, proceed with the original steps
    
    # Navigate to the directory
    cd /usr/lib/wsl/lib/
    
    # Backup existing files
    echo "Creating backups..."
    sudo cp libcuda.so libcuda.so.backup
    sudo cp libcuda.so.1 libcuda.so.1.backup
    
    # Remove the original files
    echo "Removing original files..."
    sudo rm libcuda.so
    sudo rm libcuda.so.1
    
    # Create symbolic links
    echo "Creating symbolic links..."
    sudo ln -s libcuda.so.1.1 libcuda.so
    sudo ln -s libcuda.so.1.1 libcuda.so.1
    
    # Refresh shared library cache
    echo "Refreshing shared library cache..."
    sudo ldconfig
    
    # Confirmation message
    echo "Fixed and updated. Backup files have been created."
else
    echo "No need to fix. ldconfig output is empty."
fi
